@@ -12,7 +12,8 @@ class InputObjectInfo(ObjectInfo):
                  auto_detrend_enabled=False, auto_detrend_method="cosine", auto_detrend_ratio=0.25,
                  auto_detrend_period=None, prepare_algorithm=None, reduce_simple_oscillations=False,
                  oscillation_snr_threshold=4, oscillation_amplitude_threshold=0.1, oscillation_ws_scale=60,
-                 oscillation_min_period=0.002, oscillation_max_period=0.2, object_info=1):
+                 oscillation_min_period=0.002, oscillation_max_period=0.2, object_info=1,
+                 truncate_border=0):
         """
         @param input_file: the file to be used for loading the light curve
         @param initial_mask: an array of time ranges provided to mask them into the initial object light curve.
@@ -35,13 +36,14 @@ class InputObjectInfo(ObjectInfo):
         @param oscillation_min_period: minimum period to be computed in the oscillations periodogram
         @param oscillation_max_period: maximum period to be computed in the oscillations periodogram
         @param binning: the number of cadences to be binned together
+        @param truncate_border the cadences to be eliminated for each 0.5 days separation in days
         """
         super().__init__(initial_mask, initial_transit_mask, star_info, None,
                          outliers_sigma, high_rms_enabled, high_rms_threshold, high_rms_bin_hours, smooth_enabled,
                          auto_detrend_enabled, auto_detrend_method, auto_detrend_ratio, auto_detrend_period,
                          prepare_algorithm, reduce_simple_oscillations, oscillation_snr_threshold,
                          oscillation_amplitude_threshold, oscillation_ws_scale, oscillation_min_period,
-                         oscillation_max_period, object_info)
+                         oscillation_max_period, object_info, truncate_border)
         self.input_file = input_file
 
     def sherlock_id(self):
